@@ -1,7 +1,7 @@
 bye<-function()
 {
 cat("\n")
-  file.menu <- c("Back to stability menu",
+  file.menu <- c("Back to main menu",
                  "Quit")
   cat("\n")
   pick <- menu(file.menu, title = " << Try again or quit now. >> ")
@@ -10,6 +10,6 @@ cat("\n")
      go()}
     else {
      if (pick == 2){
-        cat("\nBye~~ \n\n")}
+        cat("\nThanks for using stab for R. Bye now.\n\n")}
         }
   }
\ No newline at end of file
