@@ -30,7 +30,7 @@ cat("\n")
         }
     else {
     if (pick == 5){
-        cat("\nBye~~ \n\n")}
+        cat("\nThanks for using stab for R. Bye now.\n\n")}
          }
      }
    }
